pure-utils
==========

Yet another python utilities, with the goal of collecting useful bicycles and crutches in one place.

**Main principles**:

1. No third party dependencies (standart library only).
2. Mostly pure functions without side effects.
3. Interfaces with type annotations.
4. Comprehensive documentation with examples of use.
5. Full test coverage.

**pure-utils** is distributed on PyPI.

.. code-block:: shell-session

    $ pip install pure-utils

To use theme in your project:

.. code-block:: python

    from pure_utils import ...

    ...

Good luck)!

.. toctree::
   :caption: Utilities
   :maxdepth: 4
   :hidden:

   refs/index


.. toctree::
   :caption: Development
   :hidden:

   commands
   changelog
   license
